dsa API documentation
Description: dsa package for UC Berkeley Extension's Computer Science X404.1 Data Structures and Algorithms class Last Revision: 5/9/2024

# Package `dsa`

dsa package for UC Berkeley Extension's Computer Science X404.1 Data Structures and Algorithms class Last Revision: 5/9/2024

## Sub-modules

`dsa.array`
`dsa.deque`
`dsa.doublylinkedlist`
`dsa.graph`
`dsa.hashtable`
`dsa.heap`
`dsa.huffman`

  a collection of Huffman functions

`dsa.pretty_print`
`dsa.queue`
`dsa.singlylinkedlist`
`dsa.sorttools`

  a collection of functions for sort benchmarks

`dsa.stack`
`dsa.tree`
`dsa.trie`